stalker.ext.auth.create_session — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.ext.auth.create_session

static `auth.` `create_session`()

  Creates the beaker.session object.

  Stalker creates a session to store currently logged in user data. This function creates the session and stores it in the `stalker.ext.auth.SESSION` dictionary.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »